@@ -395,7 +395,7 @@ tuple and not inside the ``kwargs`` dictionary:
 
 ```python
 >>> printsum(y=2, x=1)
-(1, 2) {}
+(1, 2) []
 3
 
 ```
@@ -416,7 +416,7 @@ Here is how it works:
 
 ```python
 >>> printsum2(y=2, x=1)
-() {'y': 2, 'x': 1}
+() [('x', 1), ('y', 2)]
 3
 
 ```
@@ -428,7 +428,7 @@ positional, i.e. they belongs to the ``args`` tuple and not to ``kwargs``:
 
 ```python
 >>> printsum2(1, 2)
-(1, 2) {}
+(1, 2) []
 3
 
 ```
@@ -873,7 +873,7 @@ def coro_to_func(coro, *args, **kw):
      return get_event_loop().run_until_complete(coro(*args, **kw))
 ```
 
-Notice the diffence: the caller in ``log_start_stop`` was a coroutine
+Notice the difference: the caller in ``log_start_stop`` was a coroutine
 function and the associate decorator was converting coroutines in coroutines;
 the caller in ``coro_to_func`` is a regular function and converts
 coroutines -> functions.
@@ -1000,7 +1000,7 @@ inherited from the parent:
 
 ```
 
-You can introspect the precedence used by the dispath algorithm by
+You can introspect the precedence used by the dispatch algorithm by
 calling ``.dispatch_info(*types)``:
 
 ```python
@@ -1194,7 +1194,7 @@ TypeError: _memoize() got multiple values for ... 'func'
 The error message looks really strange... until you realize that
 the caller function `_memoize` uses `func` as first argument,
 so there is a confusion between the positional argument and the
-keywork arguments.
+keyword arguments.
 
 The solution is to change the name of the first argument in `_memoize`,
 or to change the implementation like so:
@@ -1815,7 +1815,7 @@ def operation2():
 
 
 def chatty(func, *args, **kwargs):
-    print(args, kwargs)
+    print(args, sorted(kwargs.items()))
     return func(*args, **kwargs)
 
 
